@@ -125,7 +125,9 @@ def ReadIqw( FileName, iqiq = True):
 def WriteBin( iqData, fSamplingRate, FileName):
     """Writes a bin file, e.g. for use on KS generators
     iqData can be a list of complex or list of floats (iqiqiq format mandatory).
-    writtenSamples = WriteBin("MyFile.bin",complexList, fs)"""
+    writtenSamples = WriteBin("MyFile.bin",complexList, fs)
+    Note: Max power is "1", i.e. I^2+Q^2<=1
+    """
 
     import struct
     from datetime import date
@@ -245,7 +247,7 @@ def ReadWv( FileName, ReadData = True):
         if( ReadData):
             data = file.read()
         else:
-            data = file.read( 6000)     # for the header, 62 kB should be sufficient
+            data = file.read( 30000)     # for the header, 30 kB should be sufficient
         file.close()
     except:
         logging.error( "File open error ("+ FileName+")!")
@@ -288,7 +290,7 @@ def ReadWv( FileName, ReadData = True):
         RfRmsLevel = NaN
 
     if ReadData:
-        data = list(struct.unpack("h"*NumberOfSamples*2, data[binaryStart:-1]))
+        data = list(struct.unpack("h"*NumberOfSamples*2, data[binaryStart:binaryStart+NumberOfSamples*4]))
         data = list(map( lambda x: x/32767.0, data ))
         data = Iqiq2Complex( data)
     
